Function lex
pub fn lex(driver: &mut Driver) -> Result<(), DriverError>Expand description
Performs lexical analysis of the source translation unit (preprocessed file) and generates a stream of tokens, and then passes ownership of the token stream to the parser stage.